@@ -1,7 +1,8 @@
 from collections import defaultdict
 from typing import TYPE_CHECKING, Any, Dict, List, Optional
 
-from moto.core import BaseModel
+from moto.core.common_models import BaseModel
+from moto.utilities.utils import get_partition
 
 from ..exceptions import (
     SWFUnknownResourceFault,
@@ -50,9 +51,9 @@ class Domain(BaseModel):
         hsh = {"name": self.name, "status": self.status}
         if self.description:
             hsh["description"] = self.description
-        hsh[
-            "arn"
-        ] = f"arn:aws:swf:{self.region_name}:{self.account_id}:/domain/{self.name}"
+        hsh["arn"] = (
+            f"arn:{get_partition(self.region_name)}:swf:{self.region_name}:{self.account_id}:/domain/{self.name}"
+        )
         return hsh
 
     def to_full_dict(self) -> Dict[str, Any]:
@@ -61,7 +62,9 @@ class Domain(BaseModel):
             "configuration": {"workflowExecutionRetentionPeriodInDays": self.retention},
         }
 
-    def get_type(self, kind: str, name: str, version: str, ignore_empty: bool = False) -> "GenericType":  # type: ignore
+    def get_type(  # type: ignore
+        self, kind: str, name: str, version: str, ignore_empty: bool = False
+    ) -> "GenericType":
         try:
             return self.types[kind][name][version]
         except KeyError:
